# Project Road Map

## 2021
We are getting very close to a beta release. Our beta release is targeted for the summer timeframe.

Our goal is to meet these requirements by the end of the year.
- We will continue investigating how we can run Tern without root privileges.
- We want to transition away from using the Docker Python library to pull container images from Dockerhub. For motivation and context, see the Kubernetes [announcement](https://kubernetes.io/blog/2020/12/02/dont-panic-kubernetes-and-docker/) and past [discussion](https://github.com/tern-tools/meetings/blob/main/minutes/04-13-2021.md) on the topic from Tern's community meeting. 
- Create a database backend with an associated API.
- Improve coverage of Tern's CI/CD pipeline. 


We will also continue to work on the following:
- We will continue to support the SPDX format for container images. To that end, we will make changes to update the format of the document as the [spec](https://spdx.org/sites/cpstandard/files/pages/files/spdxversion2.1.pdf) evolves.
- As usual, we will continue to work on our technical debt and bug fixes.

This timetable is based on time, resources and feedback from you and will change accordingly.

See archived roadmaps [here](project-roadmap-archive.md)

[Back to the README](../README.md)
